package com.zd.laboratory.mapper;

import java.util.List;
import com.zd.laboratory.domain.LabAudioSynthesis;

/**
 * 音乐合成Mapper接口
 *
 * @author zd
 * @date 2022-07-19
 */
public interface LabAudioSynthesisMapper
{
    /**
     * 查询音乐合成
     *
     * @param id 音乐合成主键
     * @return 音乐合成
     */
    LabAudioSynthesis selectLabAudioSynthesisById(Long id);

    /**
     * 查询音乐合成列表
     *
     * @param labAudioSynthesis 音乐合成
     * @return 音乐合成集合
     */
    List<LabAudioSynthesis> selectLabAudioSynthesisList(LabAudioSynthesis labAudioSynthesis);

    /**
     * 根据主键集合查询音乐合成列表
     *
     * @param ids 主键集合
     * @return 音乐合成集合
     */
    List<LabAudioSynthesis> getListByIds(List <Long> ids);

    /**
     * 新增音乐合成
     *
     * @param labAudioSynthesis 音乐合成
     * @return 结果
     */
    int insertLabAudioSynthesis(LabAudioSynthesis labAudioSynthesis);

    /**
     * 修改音乐合成
     *
     * @param labAudioSynthesis 音乐合成
     * @return 结果
     */
    int updateLabAudioSynthesis(LabAudioSynthesis labAudioSynthesis);

    /**
     * 删除音乐合成
     *
     * @param id 音乐合成主键
     * @return 结果
     */
    int deleteLabAudioSynthesisById(Long id);

    /**
     * 批量删除音乐合成
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteLabAudioSynthesisByIds(Long[] ids);
}
