package com.zd.laboratory.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.zd.common.core.domain.per.PerFun;
import com.zd.common.core.domain.per.PerPrefix;
import com.zd.common.core.web.domain.ResultData;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zd.common.log.annotation.Log;
import com.zd.common.log.enums.BusinessType;
import com.zd.common.security.annotation.PreAuthorize;
import com.zd.laboratory.domain.LabAudioSynthesis;
import com.zd.laboratory.service.ILabAudioSynthesisService;
import com.zd.common.core.web.controller.BaseController;
import com.zd.common.core.web.domain.AjaxResult;
import com.zd.common.core.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

import com.zd.common.core.web.page.TableDataInfo;

/**
 * 音乐合成Controller
 *
 * @author zd
 * @date 2022-07-19
 */
@RestController
@Api(tags = "【音乐合成】")
@RequestMapping("/synthesis")
public class LabAudioSynthesisController extends BaseController<LabAudioSynthesis>
{
    @Autowired
    private ILabAudioSynthesisService labAudioSynthesisService;

    /**
     * 查询音乐合成列表
     */
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_SYNTHESIS + PerFun.LIST)
    @GetMapping("/list")
    @ApiOperation(value = "查询音乐合成列表")
    public TableDataInfo<LabAudioSynthesis> list(LabAudioSynthesis labAudioSynthesis)
    {
        startPage();
        List<LabAudioSynthesis> list = labAudioSynthesisService.selectLabAudioSynthesisList(labAudioSynthesis);
        return getDataTable(list);
    }

    /**
     * 导出音乐合成列表
     */
    @ApiOperation(value = "导出音乐合成列表")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_SYNTHESIS + PerFun.EXPORT)
    @Log(title = "音乐合成", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LabAudioSynthesis labAudioSynthesis) throws IOException
    {
        List<LabAudioSynthesis> list = labAudioSynthesisService.selectLabAudioSynthesisList(labAudioSynthesis);
        ExcelUtil<LabAudioSynthesis> util = new ExcelUtil<LabAudioSynthesis>(LabAudioSynthesis.class);
        util.exportExcel(response, list, "音乐合成数据");
    }

    /**
     * 获取音乐合成详细信息
     */
    @ApiOperation(value = "获取音乐合成详细信息")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_SYNTHESIS + PerFun.QUERY)
    @GetMapping(value = "/{id}")
    public ResultData<LabAudioSynthesis> getInfo(@PathVariable("id") Long id)
    {
        return ResultData.success(labAudioSynthesisService.selectLabAudioSynthesisById(id));
    }

    /**
     * 新增音乐合成
     */
    @ApiOperation(value = "新增音乐合成")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_SYNTHESIS + PerFun.ADD)
    @Log(title = "音乐合成", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultData add(@RequestBody LabAudioSynthesis labAudioSynthesis, HttpServletRequest request)
    {
        return ResultData.result(labAudioSynthesisService.insertLabAudioSynthesis(labAudioSynthesis,request));
    }

    /**
     * 修改音乐合成
     */
    @ApiOperation(value = "修改音乐合成")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_SYNTHESIS + PerFun.EDIT)
    @Log(title = "音乐合成", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultData edit(@RequestBody LabAudioSynthesis labAudioSynthesis)
    {
        return  ResultData.result(labAudioSynthesisService.updateLabAudioSynthesis(labAudioSynthesis));
    }

    /**
     * 删除音乐合成
     */
    @ApiOperation(value = "删除音乐合成")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_SYNTHESIS + PerFun.REMOVE)
    @Log(title = "音乐合成", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public ResultData remove(@PathVariable Long[] ids)
    {
        return ResultData.result(labAudioSynthesisService.deleteLabAudioSynthesisByIds(ids));
    }
}
